library(lattice)

files = list.files(path = "symmetry/", pattern = "\\.log$", full.names = TRUE)

benchmark = vector(length(files), mode = "list")
names(benchmark) = files

for (f in seq_along(files)) {

  # read the files.
  benchmark[[f]] = read.table(files[f], header = TRUE)
  # recode the columns.
  benchmark[[f]][, "algorithm"] = 
    factor(benchmark[[f]][, "algorithm"], 
      levels = c("SI.HITON.PC", "MMPC", "INTER.IAMB", "GS"))
  levels(benchmark[[f]][, "algorithm"]) = c("SI-HITON-PC", "MMPC", "Inter-IAMB", "GS")
  benchmark[[f]][, "bn"] = 
    factor(benchmark[[f]][, "bn"],
      levels = c("alarm.rda", "andes.rda", "hepar2.rda", "link.rda", "munin.rda"))
  levels(benchmark[[f]][, "bn"]) = c("ALARM", "ANDES", "HEPAR II", "LINK", "MUNIN")
  benchmark[[f]][, "sample"] = 
    sub("(GS|INTER.IAMB|MMPC|SI.HITON.PC).", "", 
      sub("../code/symmetry//", "", sub(".log", "", files[f])))
  benchmark[[f]][, "sample"] = factor(benchmark[[f]][, "sample"], 
                                 levels = c("0.1", "0.2", "0.5", "1", "2", "5"))
  levels(benchmark[[f]][, "sample"]) = c("0.1", "0.2", "0.5", "1.0", "2.0", "5.0")
  # move from wide format to tall format for lattice.
  d1 = benchmark[[f]][, c("algorithm", "bn", "sample", "flip")]
  d1$optimized = FALSE
  d2 = benchmark[[f]][, c("algorithm", "bn", "sample", "flip2")]
  d2$optimized = TRUE
  colnames(d2) = colnames(d1)
  benchmark[[f]] = rbind(d1, d2)

}#FOR

merged = do.call("rbind", benchmark)

at = list(c(0, 10, 15), c(0, 20, 40), c(0, 10, 15), c(0, 120, 210), c(150, 250, 340),
          c(0, 10, 15), c(0, 40, 60), c(0, 15, 30), c(20, 120, 280), c(120, 200, 340),
          c(0, 10, 20), c(0, 50, 80), c(0, 20, 45), c(20, 120, 350), c(120, 260, 360),
          c(10, 20, 25), c(80, 110, 140), c(10, 20, 30), c(150, 200, 250), c(100, 150, 300))

trellis.par.set(list(box.dot = list(pch = "|", alpha = 1),
                     box.rectangle = list(col = "black"),
                     box.umbrella = list(col = "black", lty = 1),
                     plot.symbol = list(alpha = 0)))

print(bwplot(sample ~ flip | bn + algorithm, data = merged, 
  group = merged$optimized, strip = FALSE,
  scales = list(alternating = c(1), x = list(relation = "free", at = at)),
  xlab = "Hamming distance", xlab.top = levels(merged$bn), 
  ylab = "n/p", ylab.right = list(levels(merged$algorithm), rot = 270),
  panel = function(...) {

    panel.superpose(...)

  },
  panel.groups = function(x, y, ..., group.number) {

    panel.bwplot(x, y + (1.5 - group.number)/2.5, box.width = 0.3,
      fill = c("steelblue", "limegreen")[group.number])

  }))

