#!/usr/bin/Rscript

library(lattice)
library(doBy)

secs.to.string = function(x) {

  format(as.POSIXct('0001-01-01 00:00:00') + x, "%M:%S")

}#SECS.TO.STRING

lgs = read.table("benchmarks/link.gs20k.timings.txt", header = TRUE, stringsAsFactors = FALSE)
mgs = read.table("benchmarks/munin.gs20k.timings.txt", header = TRUE, stringsAsFactors = FALSE)
liamb = read.table("benchmarks/link.iamb20k.timings.txt", header = TRUE, stringsAsFactors = FALSE)
miamb = read.table("benchmarks/munin.iamb20k.timings.txt", header = TRUE, stringsAsFactors = FALSE)
lmmpc = read.table("benchmarks/link.mmpc20k.timings.txt", header = TRUE, stringsAsFactors = FALSE)
mmmpc = read.table("benchmarks/munin.mmpc20k.timings.txt", header = TRUE, stringsAsFactors = FALSE)
lhiton = read.table("benchmarks/link.hiton20k.timings.txt", header = TRUE, stringsAsFactors = FALSE)
mhiton = read.table("benchmarks/munin.hiton20k.timings.txt", header = TRUE, stringsAsFactors = FALSE)

lopt = read.table("../code/benchmarks/link.opt.timings.txt", header = TRUE, stringsAsFactors = FALSE)
mopt = read.table("../code/benchmarks/munin.opt.timings.txt", header = TRUE, stringsAsFactors = FALSE)

lgs$BN = liamb$BN = lmmpc$BN = lhiton$BN = lopt$BN = "LINK"
mgs$BN = miamb$BN = mmmpc$BN = mhiton$BN = mopt$BN = "MUNIN"
lopt$PROCS = mopt$PROCS = 1.5

merged = rbind(lgs, mgs, liamb, miamb, lmmpc, mmmpc, lhiton, mhiton, lopt, mopt)
merged$BN = factor(merged$BN, levels = c("LINK", "MUNIN"))
merged$ALGO = factor(merged$ALGO, levels = c("HITON", "MMPC", "IAMB", "GS"))
levels(merged$ALGO)[levels(merged$ALGO) == "HITON"] = "SI-HITON-PC"
levels(merged$ALGO)[levels(merged$ALGO) == "IAMB"] = "Inter-IAMB"

merged2 = summaryBy(TIME ~ ALGO + BN + PROCS, data = merged, FUN = mean)
names(merged2)[4] = c("MEAN")

y.tcks = merged2[merged2$PROCS %in% c(1, 2, 8), "MEAN"]
y.tcks = split(y.tcks, f = c(rep(1, 3), rep(2, 3), rep(3, 3), rep(4, 3), 
           rep(5, 3), rep(6, 3), rep(7, 3), rep(8, 3)))
y.labls = lapply(y.tcks, function(x) round(x/x[1], 3))

print(xyplot(MEAN ~ PROCS | BN + ALGO, data = merged2,
  ylab = "normalised running time", xlab = "number of slaves",
  main = "MUNIN and LINK Reference Networks", strip = FALSE,
  scales = list(alternating = c(1), x = list(at = c(1, 2, 3, 4, 6, 8), relation = "free"),
             y = list(at = y.tcks, labels = y.labls, relation = "free", rot = 90)),
  xlab.top = levels(merged$BN), ylab.right = list(levels(merged$ALGO), rot = 270),
  panel = function(x, y, ...) {

    panel.abline(h = y[x %in% c(1, 2, 8)], col = "lightgrey")
    panel.lines(x = c(1, 1), y = c(0, y[x == 1]), col = "lightgrey", lty = 2)
    panel.text(x = 8, y = y[x == 1] * 0.95, pos = 2, secs.to.string(y[x == 1]), font = 2)
    panel.text(x = 8, y = y[x == 2] * 1.10, pos = 2, secs.to.string(y[x == 2]))
    panel.text(x = 1, y = y[x == 8] * 1.30, pos = 4, secs.to.string(y[x == 8]), font = 2)
    panel.text(x = 4, y = mean(y[x %in% 1:2]), pos = 4, 
      paste("OPTIMISED:", secs.to.string(y[x == 1.5])))
    panel.lines(x = c(1, 3.8), y = c(y[x == 1.5], mean(y[x %in% 1:2])), col = 2)
    panel.points(x = 1, y = y[x == 1.5], col = "red", pch = 19)
    panel.xyplot(x = x[x != 1.5], y = y[x != 1.5], type = "b", pch = 19)

  }
))

