#!/usr/bin/Rscript

library(lattice)
library(gridExtra)
library(doBy)

sts = function(x) {

  format(as.POSIXct('0001-01-01 00:00:00') + x, "%H:%M:%S")

}#SECS.TO.STRING

carcinoma = read.table("benchmarks/carcinoma.hiton.timings.txt", header = TRUE, stringsAsFactors = FALSE)
d = summaryBy(SECS ~ PROCS, data = carcinoma, FUN = mean)
names(d)[2] = "MEAN"
d$PROCS[d$PROCS == "OPT"] = 1.5
d$PROCS = as.numeric(d$PROCS)
d = d[order(d$PROCS), ]

p1 = xyplot(MEAN ~ PROCS, data = d,
  ylab = "normalised running time", xlab = "number of slaves",
  main = "Lung Adenocarcinoma",
  scales = list(tck = c(1, 0), x = list(at = c(1:4, seq(from = 6, to = 20, by = 2))), 
                y = list(at = d[d$PROCS %in% c(1, 2, 3, 4, 20), "MEAN"], rot = 90,
                      labels = round(d[d$PROCS %in% c(1, 2, 3, 4, 20), "MEAN"]/d[1, "MEAN"], 3))),
  panel = function(x, y, ...) {

    panel.abline(h = y[x %in% c(1:4, 20)], col = "lightgrey")
    panel.lines(x = c(1, 1), y = c(y[x == 1], y[x == 20]), col = "lightgrey", lty = 2)
    panel.text(x = 20, y = y[x %in% 1:4] + 1500, pos = 2,
      sts(y[x %in% 1:4]), font = c(2, 1, 1, 1))
    panel.text(x = 1, y = y[x == 20] + 1500, pos = 4, sts(y[12]), font = 2)
    panel.text(x = 4, y = mean(y[x %in% 1:2]), pos = 4, 
      paste("OPTIMISED:", sts(y[x == 1.5])))
    panel.lines(x = c(1, 3.9), y = c(y[x == 1.5], mean(y[x %in% 1:2])), col = 2)
    panel.points(x = 1, y = y[x == 1.5], col = "red", pch = 19)
    panel.xyplot(x = x[x != 1.5], y = y[x != 1.5], pch = 19, type = "b")

  }
)

mice = read.table("benchmarks/mice.hiton.timings.txt", header = TRUE, stringsAsFactors = FALSE)
d = summaryBy(SECS ~ PROCS, data = mice, FUN = mean)
names(d)[2] = "MEAN"
d$PROCS[d$PROCS == "OPT"] = 1.5
d$PROCS = as.numeric(d$PROCS)
d = d[order(d$PROCS), ]

p2 = xyplot(MEAN ~ PROCS, data = d,
  ylab = "normalised running time", xlab = "number of slaves",
  main = "WTCCC Heterogeneous Mice Population",
  scales = list(tck = c(1, 0), x = list(at = c(1:4, seq(from = 6, to = 20, by = 2))),
                y = list(at = d[d$PROCS %in% c(1, 2, 3, 4, 20), "MEAN"], rot = 90,
                      labels = format(round(d[d$PROCS %in% c(1, 2, 3, 4, 20), "MEAN"]/d[1, "MEAN"], 3), digits = 5))),
  panel = function(x, y, ...) {

    panel.abline(h = y[x %in% c(1:4, 20)], col = "lightgrey")
    panel.lines(x = c(1, 1), y = c(y[x == 1], y[x == 20]), col = "lightgrey", lty = 2)
    panel.text(x = 20, y = y[x %in% 1:4] + 600, pos = 2,
       sts(y[x %in% 1:4]), font = c(2, 1, 1, 1))
    panel.text(x = 1, y = y[x == 20] + 600, pos = 4, sts(y[12]), font = 2)
    panel.text(x = 4, y = mean(y[x %in% 1:2]), pos = 4, 
      paste("OPTIMISED:", sts(y[x == 1.5])))
    panel.lines(x = c(1, 3.9), y = c(y[x == 1.5], mean(y[x %in% 1:2])), col = 2)
    panel.points(x = 1, y = y[x == 1.5], col = "red", pch = 19)
    panel.xyplot(x = x[x != 1.5], y = y[x != 1.5], pch = 19, type = "b")

  }
)

grid.arrange(p1, p2, ncol = 1)

