library(parallel)
library(bnlearn)

# load the MUNIN reference network.
load("link.rda")
# set the random seed.
set.seed(123)
# generate a data set from the network.
data = rbn(bn, n = 20000)

nprocs = c(1, 2, 3, 4, 6, 8)
run = 1:10
elapsed = numeric(0)

for (r in run) {

  # get the running time.
  t = system.time(si.hiton.pc(data, optimized = FALSE, alpha = 0.05))
  # save the elapsed time.
  elapsed = c(elapsed, t["elapsed"])
  # debugging output.
  cat("NPROCS: ", 1, "TIME:", t["elapsed"], "\n")

}#FOR

# these are for parallel execution.
for (np in nprocs[-1]) {

  # start the cluster with the correct number of forks.
  cl = makeCluster(np, type = "SOCK")

  for (r in run) {

    # get the running time.
    t = system.time(si.hiton.pc(data, cluster = cl, alpha = 0.05))
    # save the elapsed time.
    elapsed = c(elapsed, t["elapsed"])
    # debugging output.
    cat("NPROCS: ", np, "TIME:", t["elapsed"], "\n")

  }#FOR

  # stop the cluster.
  stopCluster(cl)

}#FOR

timings = data.frame(
  PROCS = c(rep(1, length(run)), rep(2, length(run)), rep(3, length(run)), 
            rep(4, length(run)), rep(6, length(run)), rep(8, length(run))),
  ALGO = rep("HITON", length(run) * length(nprocs)),
  RUN = rep(run, length(nprocs)),
  TIME = elapsed
)

write.table(timings, file = "link.hiton20k.timings.txt", row.names = FALSE)

