library(bnlearn)

# load the MUNIN reference network.
load("link.rda")
# set the random seed.
set.seed(123)
# generate a data set from the network.
data = rbn(bn, n = 20000)

run = 1:10
elapsed = numeric(0)

for (r in run) {

  # get the running time.
  t = system.time(gs(data, optimized = TRUE, alpha = 0.05))
  # save the elapsed time.
  elapsed = c(elapsed, t["elapsed"])
  # debugging output.
  cat("GROW-SHRINK TIME:", t["elapsed"], "\n")

}#FOR

for (r in run) {

  # get the running time.
  t = system.time(inter.iamb(data, optimized = TRUE, alpha = 0.05))
  # save the elapsed time.
  elapsed = c(elapsed, t["elapsed"])
  # debugging output.
  cat("INTER-IAMB TIME:", t["elapsed"], "\n")

}#FOR

for (r in run) {

  # get the running time.
  t = system.time(mmpc(data, optimized = TRUE, alpha = 0.05))
  # save the elapsed time.
  elapsed = c(elapsed, t["elapsed"])
  # debugging output.
  cat("MMPC TIME:", t["elapsed"], "\n")

}#FOR

for (r in run) {

  # get the running time.
  t = system.time(si.hiton.pc(data, optimized = TRUE, alpha = 0.05))
  # save the elapsed time.
  elapsed = c(elapsed, t["elapsed"])
  # debugging output.
  cat("SI-HITON-PC TIME:", t["elapsed"], "\n")

}#FOR

timings = data.frame(
  PROCS = rep("OPT", 4 * length(run)),
  ALGO = c(rep("GS", length(run)), rep("IAMB", length(run)), 
           rep("MMPC", length(run)), rep("HITON", length(run))),
  RUN = rep(run, 4),
  TIME = elapsed
)

write.table(timings, file = "link.opt.timings.txt", row.names = FALSE)

