library(parallel)
library(bnlearn)

source("dedup.R")

xzfd = xzfile("prepd-mice.txt.xz")
data = read.table(xzfd, header = TRUE, colClasses = "numeric")
data = dedup(data[, -(1:2)], threshold = 0.95)

nprocs = c(1, 2, 3, 4, 6, 8)
run = 1:5
elapsed = numeric(0)

for (r in run) {

  # get the running time.
  t = system.time(si.hiton.pc(data, optimized = FALSE, alpha = 0.01))
  # save the elapsed time.
  elapsed = c(elapsed, t["elapsed"])
  # debugging output.
  cat("NPROCS: ", 1, "TIME:", t["elapsed"], "\n")

}#FOR

# these are for parallel execution.
for (np in nprocs[-1]) {

  # start the cluster with the correct number of forks.
  cl = makeCluster(np, type = "SOCK")

  for (r in run) {

    # get the running time.
    t = system.time(si.hiton.pc(data, cluster = cl, alpha = 0.01))
    # save the elapsed time.
    elapsed = c(elapsed, t["elapsed"])
    # debugging output.
    cat("NPROCS: ", np, "TIME:", t["elapsed"], "\n")

  }#FOR

  # stop the cluster.
  stopCluster(cl)

}#FOR

timings = data.frame(
  PROCS = c(rep(1, length(run)), rep(2, length(run)), rep(3, length(run)), 
            rep(4, length(run)), rep(6, length(run)), rep(8, length(run))),
  RUN = rep(run, length(nprocs)),
  SECS = round(elapsed, digits = 3)
)

write.table(timings, file = "mice.hiton.timings.txt", row.names = FALSE)

